/*
 *  This file is part of Player Analytics (Plan).
 *
 *  Plan is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License v3 as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Plan is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Plan. If not, see <https://www.gnu.org/licenses/>.
 */
package com.djrapitops.plan.gathering.domain;

import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
import java.util.Optional;

public class DataMap {

    private final Map<String, Object> data;

    public DataMap() {
        this.data = new HashMap<>();
    }

    private DataMap(Map<String, Object> data) {
        this.data = new HashMap<>(data);
    }

    public <T> void put(Class<T> type, T value) {
        data.put(type.getName(), value);
    }

    public <T> Optional<T> get(Class<T> ofType) {
        return Optional.ofNullable(ofType.cast(data.get(ofType.getName())));
    }

    public void remove(Class<?> ofType) {
        data.remove(ofType.getName());
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        DataMap dataMap = (DataMap) o;
        return Objects.equals(data, dataMap.data);
    }

    @Override
    public int hashCode() {
        return Objects.hash(data);
    }

    @Override
    public String toString() {
        return "DataMap{" +
                "data=" + data +
                '}';
    }

    public DataMap copy() {
        return new DataMap(data);
    }
}
